==============================================================
*environ-config*: Application Configuration With Env Variables
==============================================================

Release v\ |release| (:doc:`What's new? <changelog>`).


.. include:: ../README.rst
   :start-after: -teaser-begin-
   :end-before: -teaser-end-


User's Guide
------------

.. toctree::
   :maxdepth: 2

   tutorial
   api


Project Information
-------------------

.. toctree::
   :maxdepth: 1

   license
   contributing
   backward-compatibility
   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
